# ToyRL

[![Python](https://img.shields.io/pypi/pyversions/toyrl.svg?color=%2334D058)](https://pypi.org/project/toyrl/)
[![PyPI](https://img.shields.io/pypi/v/toyrl?color=%2334D058&label=pypi%20package)](https://pypi.org/project/toyrl/)
[![PyPI Downloads](https://static.pepy.tech/badge/toyrl)](https://pepy.tech/projects/toyrl)
[![GitHub License](https://img.shields.io/github/license/ai-glimpse/toyrl)](https://github.com/ai-glimpse/toyrl/blob/master/LICENSE)

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Build Docs](https://github.com/ai-glimpse/toyrl/actions/workflows/build_docs.yaml/badge.svg)](https://github.com/ai-glimpse/toyrl/actions/workflows/build_docs.yaml)
[![Test](https://github.com/ai-glimpse/toyrl/actions/workflows/test.yaml/badge.svg)](https://github.com/ai-glimpse/toyrl/actions/workflows/test.yaml)
[![Codecov](https://codecov.io/gh/ai-glimpse/toyrl/branch/master/graph/badge.svg)](https://codecov.io/gh/ai-glimpse/toyrl)

## Documentation

[https://ai-glimpse.github.io/toyrl](https://ai-glimpse.github.io/toyrl)

## Installation

```bash
pip install toyrl
```

## Algorithms

- [x] REINFORCE
- [x] SARSA
- [ ] DQN
